@@ -3,10 +3,10 @@ from .models import LogMixin
 from .views import ActionFromUrl, Filterable, PermissionRequired, Sortable
 
 __all__ = [
-    'ActionFromUrl',
-    'Filterable',
-    'LogMixin',
-    'PermissionRequired',
-    'ReadOnlyFlag',
-    'Sortable',
+    "ActionFromUrl",
+    "Filterable",
+    "LogMixin",
+    "PermissionRequired",
+    "ReadOnlyFlag",
+    "Sortable",
 ]
